import {FileChangeType}from'../interfaces/files.js';import'../interfaces/textfiles.js';import'../interfaces/error-codes.js';import'../interfaces/generated-models.js';import {isLinux}from'@vscode-alt/monaco-editor/esm/vs/base/common/platform.js';import {isUndefinedOrNull}from'@vscode-alt/monaco-editor/esm/vs/base/common/types.js';import {isEqualOrParent,isEqual}from'@vscode-alt/monaco-editor/esm/vs/base/common/resources.js';/* tslint:disable */
class FileChangesEvent {
  _changes;
  constructor(changes) {
    this._changes = changes;
  }
  get changes() {
    return this._changes;
  }
  /**
   * Returns true if this change event contains the provided file with the given change type (if provided). In case of
   * type DELETED, this method will also return true if a folder got deleted that is the parent of the
   * provided file path.
   */
  contains(resource, type) {
    if (!resource) {
      return false;
    }
    const checkForChangeType = !isUndefinedOrNull(type);
    return this._changes.some(change => {
      if (checkForChangeType && change.type !== type) {
        return false;
      }
      // For deleted also return true when deleted folder is parent of target path
      if (change.type === FileChangeType.DELETED) {
        return isEqualOrParent(resource, change.resource, !isLinux /* ignorecase */);
      }
      return isEqual(resource, change.resource, !isLinux /* ignorecase */);
    });
  }
  /**
   * Returns the changes that describe added files.
   */
  getAdded() {
    return this.getOfType(FileChangeType.ADDED);
  }
  /**
   * Returns if this event contains added files.
   */
  gotAdded() {
    return this.hasType(FileChangeType.ADDED);
  }
  /**
   * Returns the changes that describe deleted files.
   */
  getDeleted() {
    return this.getOfType(FileChangeType.DELETED);
  }
  /**
   * Returns if this event contains deleted files.
   */
  gotDeleted() {
    return this.hasType(FileChangeType.DELETED);
  }
  /**
   * Returns the changes that describe updated files.
   */
  getUpdated() {
    return this.getOfType(FileChangeType.UPDATED);
  }
  /**
   * Returns if this event contains updated files.
   */
  gotUpdated() {
    return this.hasType(FileChangeType.UPDATED);
  }
  getOfType(type) {
    return this._changes.filter(change => change.type === type);
  }
  hasType(type) {
    return this._changes.some(change => {
      return change.type === type;
    });
  }
}export{FileChangesEvent};//# sourceMappingURL=file-changes-event.js.map
